class AlphaValidator < ActiveModel::EachValidator

  def validate_each(record, attribute, value)
    unless valid?(value, options)
      record.errors[attribute] << (options[:message] || I18n.t('flash_validators.errors.messages.alpha'))
    end
  end

  private

  def valid_format?(value, options)
    case options[:case]
    when :lower
      options[:strict] ? (value =~ /^[a-z]+$/) : (value =~ /^[a-z ]+$/)
    when :upper
      options[:strict] ? (value =~ /^[A-Z]+$/) : (value =~ /^[A-Z ]+$/)
    else
      options[:strict] ? (value =~ /^[A-Za-z]+$/i) : (value =~ /^[A-Za-z ]+$/i)
    end
  end

  def valid_length?(value)
    value != ' '
  end

  def valid?(value, options)
    valid_format?(value, options) &&
    valid_length?(value)
  end

end