class ImeiValidator < ActiveModel::EachValidator

  def validate_each(record, attribute, value)
    unless valid?(value.to_s)
      record.errors[attribute] << (options[:message] || I18n.t('flash_validators.errors.messages.imei'))
    end
  end

  private

  def valid_format?(value)
    value =~ /\A[\d\.\:\-\s]+\z/i
  end

  def valid_luhn?(value)
    numbers = value.gsub(/\D/, '').reverse

    sum, i = 0, 0

    numbers.each_char do |ch|
      n = ch.to_i
      n *= 2 if i.odd?
      n = 1 + (n - 10) if n >= 10

      sum += n
      i   += 1
    end

    (sum % 10).zero?
  end

  def valid?(value)
    valid_format?(value) &&
    valid_luhn?(value)
  end

end